@@ -15,8 +15,7 @@ ghermite.h.inner.products <- function( n, mu )
         stop( "highest polynomial order is not integer" )
     if ( mu <= -0.5 )
         stop( "mu less than or equal to -0.5" )
-    almost.hermite.h <- abs( mu ) < 1e-6
-    if ( mu == 0 )
+    if ( abs( mu ) < 1e-6 )
         return( hermite.h.inner.products( n ) )
     inner.products <- rep( 1, n + 1 )
     sqrt.pi <- sqrt( pi )
